==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeText.h <==
// class gnu.xml.libxmlj.dom.GnomeText

// class file dependencies
// @dep_class e9dbbaa1abefd77b gnu_xml_libxmlj_dom_GnomeCharacterData
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 6dd1f7372acd9c60 gnu_xml_libxmlj_dom_GnomeText
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeCharacterData

#include "gnu/xml/libxmlj/dom/GnomeCharacterData.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeText_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeText_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Text$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$refs	_jc_gnu_xml_libxmlj_dom_GnomeText$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeText$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$object	_jc_gnu_xml_libxmlj_dom_GnomeText$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeText$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeText$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeText$vtable	_jc_gnu_xml_libxmlj_dom_GnomeText$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeText$vtype	_jc_gnu_xml_libxmlj_dom_GnomeText$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeText$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeText$method$getWholeText$616760a53205c85e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *);
extern jboolean _jc_gnu_xml_libxmlj_dom_GnomeText$method$isElementContentWhitespace$a795084c81702e72(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *);
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeText$method$replaceWholeText$58ca24958074b07d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeText$method$splitText$5d5d3b9a4091250a(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeText$method_info$getWholeText$616760a53205c85e;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeText$method_info$isElementContentWhitespace$a795084c81702e72;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeText$method_info$replaceWholeText$58ca24958074b07d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeText$method_info$splitText$5d5d3b9a4091250a;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeText$vmethods {
	struct _jc_java_lang_String$object	*(*getWholeText$616760a53205c85e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *);
	jboolean	(*isElementContentWhitespace$a795084c81702e72)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *);
	struct _jc_object	*(*replaceWholeText$58ca24958074b07d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*splitText$5d5d3b9a4091250a)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, jint);
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeText$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeCharacterData$vmethods	gnu_xml_libxmlj_dom_GnomeCharacterData;
	_jc_gnu_xml_libxmlj_dom_GnomeText$vmethods	gnu_xml_libxmlj_dom_GnomeText;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeText$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeText$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeText$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs	gnu_xml_libxmlj_dom_GnomeText;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_refs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeText$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeText;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeText$object {
	_jc_gnu_xml_libxmlj_dom_GnomeText$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeText$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeText$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeText$vtype _jc_gnu_xml_libxmlj_dom_GnomeText$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeText, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeText$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeText_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeText.h <==
// class gnu.xml.libxmlj.dom.GnomeText

// class file dependencies
// @dep_class e9dbbaa1abefd77b gnu_xml_libxmlj_dom_GnomeCharacterData
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 6dd1f7372acd9c60 gnu_xml_libxmlj_dom_GnomeText
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeCharacterData

#include "gnu/xml/libxmlj/dom/GnomeCharacterData.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeText_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeText_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Text$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$refs	_jc_gnu_xml_libxmlj_dom_GnomeText$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeText$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeText$object	_jc_gnu_xml_libxmlj_dom_GnomeText$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeText$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeText$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeText$vtable	_jc_gnu_xml_libxmlj_dom_GnomeText$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeText$vtype	_jc_gnu_xml_libxmlj_dom_GnomeText$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeText$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_libxmlj_dom_GnomeText$method$getWholeText$616760a53205c85e(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_xml_libxmlj_dom_GnomeText$method$isElementContentWhitespace$a795084c81702e72(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeText$method$replaceWholeText$58ca24958074b07d(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_xml_libxmlj_dom_GnomeText$method$splitText$5d5d3b9a4091250a(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeText$method_info$getWholeText$616760a53205c85e;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeText$method_info$isElementContentWhitespace$a795084c81702e72;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeText$method_info$replaceWholeText$58ca24958074b07d;
extern _jc_method _jc_gnu_xml_libxmlj_dom_GnomeText$method_info$splitText$5d5d3b9a4091250a;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeText$vmethods {
	struct _jc_java_lang_String$object	*(*getWholeText$616760a53205c85e)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *) _JC_JCNI_ATTR;
	jboolean	(*isElementContentWhitespace$a795084c81702e72)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*replaceWholeText$58ca24958074b07d)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*splitText$5d5d3b9a4091250a)(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeText$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeText$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeCharacterData$vmethods	gnu_xml_libxmlj_dom_GnomeCharacterData;
	_jc_gnu_xml_libxmlj_dom_GnomeText$vmethods	gnu_xml_libxmlj_dom_GnomeText;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeText$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeText$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeText$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeText$sub_refs	gnu_xml_libxmlj_dom_GnomeText;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_refs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeText$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeCharacterData$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeCharacterData;
    _jc_gnu_xml_libxmlj_dom_GnomeText$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeText;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeText$object {
	_jc_gnu_xml_libxmlj_dom_GnomeText$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeText$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeText$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeText$vtype _jc_gnu_xml_libxmlj_dom_GnomeText$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeText, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeText$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeText_H_ */
